/*******************************************************************************
* File Name: OLED_CTRL.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "OLED_CTRL.h"


/*******************************************************************************
* Function Name: OLED_CTRL_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void OLED_CTRL_Write(uint8 value) 
{
    uint8 staticBits = (OLED_CTRL_DR & (uint8)(~OLED_CTRL_MASK));
    OLED_CTRL_DR = staticBits | ((uint8)(value << OLED_CTRL_SHIFT) & OLED_CTRL_MASK);
}


/*******************************************************************************
* Function Name: OLED_CTRL_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  OLED_CTRL_DM_STRONG     Strong Drive 
*  OLED_CTRL_DM_OD_HI      Open Drain, Drives High 
*  OLED_CTRL_DM_OD_LO      Open Drain, Drives Low 
*  OLED_CTRL_DM_RES_UP     Resistive Pull Up 
*  OLED_CTRL_DM_RES_DWN    Resistive Pull Down 
*  OLED_CTRL_DM_RES_UPDWN  Resistive Pull Up/Down 
*  OLED_CTRL_DM_DIG_HIZ    High Impedance Digital 
*  OLED_CTRL_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void OLED_CTRL_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(OLED_CTRL_0, mode);
	CyPins_SetPinDriveMode(OLED_CTRL_1, mode);
	CyPins_SetPinDriveMode(OLED_CTRL_2, mode);
}


/*******************************************************************************
* Function Name: OLED_CTRL_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro OLED_CTRL_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 OLED_CTRL_Read(void) 
{
    return (OLED_CTRL_PS & OLED_CTRL_MASK) >> OLED_CTRL_SHIFT;
}


/*******************************************************************************
* Function Name: OLED_CTRL_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 OLED_CTRL_ReadDataReg(void) 
{
    return (OLED_CTRL_DR & OLED_CTRL_MASK) >> OLED_CTRL_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(OLED_CTRL_INTSTAT) 

    /*******************************************************************************
    * Function Name: OLED_CTRL_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 OLED_CTRL_ClearInterrupt(void) 
    {
        return (OLED_CTRL_INTSTAT & OLED_CTRL_MASK) >> OLED_CTRL_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
