/*******************************************************************************
* File Name: SS_CON.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SS_CON.h"


/*******************************************************************************
* Function Name: SS_CON_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void SS_CON_Write(uint8 value) 
{
    uint8 staticBits = (SS_CON_DR & (uint8)(~SS_CON_MASK));
    SS_CON_DR = staticBits | ((uint8)(value << SS_CON_SHIFT) & SS_CON_MASK);
}


/*******************************************************************************
* Function Name: SS_CON_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  SS_CON_DM_STRONG     Strong Drive 
*  SS_CON_DM_OD_HI      Open Drain, Drives High 
*  SS_CON_DM_OD_LO      Open Drain, Drives Low 
*  SS_CON_DM_RES_UP     Resistive Pull Up 
*  SS_CON_DM_RES_DWN    Resistive Pull Down 
*  SS_CON_DM_RES_UPDWN  Resistive Pull Up/Down 
*  SS_CON_DM_DIG_HIZ    High Impedance Digital 
*  SS_CON_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void SS_CON_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(SS_CON_0, mode);
}


/*******************************************************************************
* Function Name: SS_CON_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SS_CON_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SS_CON_Read(void) 
{
    return (SS_CON_PS & SS_CON_MASK) >> SS_CON_SHIFT;
}


/*******************************************************************************
* Function Name: SS_CON_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SS_CON_ReadDataReg(void) 
{
    return (SS_CON_DR & SS_CON_MASK) >> SS_CON_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SS_CON_INTSTAT) 

    /*******************************************************************************
    * Function Name: SS_CON_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SS_CON_ClearInterrupt(void) 
    {
        return (SS_CON_INTSTAT & SS_CON_MASK) >> SS_CON_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
